@@ -12,8 +12,10 @@
 #include <Rembedded.h>
 #include <Rversion.h>
 #include <Rdefines.h>
+#ifndef WIN32
 #define R_INTERFACE_PTRS
 #include <Rinterface.h>
+#endif
 #include <R_ext/Parse.h>
 
 #include "MemBuf.h"
@@ -43,3 +45,12 @@ public:
     ~RInside();
 };
 
+// simple logging help
+inline void logTxtFunction(const char* file, const char* line, const char* expression, const bool verbose) {
+    if (verbose) {
+	std::cout << file << ":" << line << " expression: " << expression << std::endl;
+    }
+}
+
+//#define logTxt(x, b) logTxtFunction(__FILE__, __LINE__, x, b);
+#define logTxt(x, b) 
